@@ -21,16 +21,17 @@ use std::convert::TryFrom;
 use ergo_lib::ergotree_ir::chain;
 use ergo_lib::ergotree_ir::chain::ergo_box::NonMandatoryRegisters;
 use ergo_lib::ergotree_ir::serialization::SigmaSerializable;
+use ergo_lib::wallet::tx_builder::new_miner_fee_box;
 use js_sys::Uint8Array;
 use wasm_bindgen::prelude::*;
 
-use crate::ast::Constant;
+use crate::contract::Contract;
 use crate::ergo_tree::ErgoTree;
 use crate::error_conversion::to_js;
 use crate::json::ErgoBoxJsonEip12;
 use crate::token::Tokens;
 use crate::utils::I64;
-use crate::{contract::Contract, transaction::TxId};
+use crate::{ast::Constant, transaction::TxId};
 
 extern crate derive_more;
 use derive_more::{From, Into};
@@ -70,6 +71,16 @@ pub struct ErgoBoxCandidate(chain::ergo_box::ErgoBoxCandidate);
 
 #[wasm_bindgen]
 impl ErgoBoxCandidate {
+    /// Create a box with miner's contract and given value
+    pub fn new_miner_fee_box(
+        fee_amount: &BoxValue,
+        creation_height: u32,
+    ) -> Result<ErgoBoxCandidate, JsValue> {
+        Ok(new_miner_fee_box(fee_amount.into(), creation_height)
+            .map_err(to_js)?
+            .into())
+    }
+
     /// Returns value (ErgoTree constant) stored in the register or None if the register is empty
     pub fn register_value(&self, register_id: NonMandatoryRegisterId) -> Option<Constant> {
         self.0
@@ -178,7 +189,7 @@ impl ErgoBox {
             .map_err(|e| JsValue::from_str(&format!("{}", e)))
     }
 
-    /// JSON representation according to EIP-12 https://github.com/ergoplatform/eips/pull/23
+    /// JSON representation according to EIP-12 <https://github.com/ergoplatform/eips/pull/23>
     /// (similar to [`Self::to_json`], but as JS object with box value and token amounts encoding as strings)
     pub fn to_js_eip12(&self) -> Result<JsValue, JsValue> {
         let box_dapp: ErgoBoxJsonEip12 = self.0.clone().into();
@@ -199,6 +210,18 @@ impl ErgoBox {
             .sigma_serialize_bytes()
             .map_err(|e| JsValue::from_str(&format!("{}", e)))
     }
+
+    /// Returns serialized bytes or fails with error if cannot be serialized
+    pub fn sigma_serialize_bytes(&self) -> Result<Vec<u8>, JsValue> {
+        self.0.sigma_serialize_bytes().map_err(to_js)
+    }
+
+    /// Parses ErgoBox or fails with error
+    pub fn sigma_parse_bytes(data: Vec<u8>) -> Result<ErgoBox, JsValue> {
+        chain::ergo_box::ErgoBox::sigma_parse_bytes(&data)
+            .map(ErgoBox)
+            .map_err(to_js)
+    }
 }
 
 impl From<ErgoBox> for chain::ergo_box::ErgoBox {
@@ -215,7 +238,7 @@ impl From<chain::ergo_box::ErgoBox> for ErgoBox {
 
 /// Box value in nanoERGs with bound checks
 #[wasm_bindgen]
-#[derive(PartialEq, Eq, Debug, Clone)]
+#[derive(PartialEq, Eq, Debug, Clone, From, Into)]
 pub struct BoxValue(pub(crate) chain::ergo_box::box_value::BoxValue);
 
 #[wasm_bindgen]
@@ -252,18 +275,12 @@ impl BoxValue {
     }
 }
 
-impl From<BoxValue> for chain::ergo_box::box_value::BoxValue {
-    fn from(v: BoxValue) -> Self {
+impl From<&BoxValue> for chain::ergo_box::box_value::BoxValue {
+    fn from(v: &BoxValue) -> Self {
         v.0
     }
 }
 
-impl From<chain::ergo_box::box_value::BoxValue> for BoxValue {
-    fn from(v: chain::ergo_box::box_value::BoxValue) -> Self {
-        BoxValue(v)
-    }
-}
-
 /// Pair of <value, tokens> for an box
 #[wasm_bindgen]
 #[derive(PartialEq, Eq, Debug, Clone, From, Into)]
@@ -271,7 +288,7 @@ pub struct ErgoBoxAssetsData(ergo_lib::wallet::box_selector::ErgoBoxAssetsData);
 
 #[wasm_bindgen]
 impl ErgoBoxAssetsData {
-    /// Create empty SimpleBoxSelector
+    /// Create new instance
     #[wasm_bindgen(constructor)]
     pub fn new(value: &BoxValue, tokens: &Tokens) -> Self {
         ErgoBoxAssetsData(ergo_lib::wallet::box_selector::ErgoBoxAssetsData {
