@@ -13,6 +13,8 @@
 // Clippy warnings
 #![allow(clippy::new_without_default)]
 #![allow(clippy::len_without_is_empty)]
+#![allow(clippy::unused_unit)]
+#![deny(clippy::wildcard_enum_match_arm)]
 
 pub mod address;
 pub mod ast;
@@ -27,7 +29,11 @@ pub mod ergo_state_ctx;
 pub mod ergo_tree;
 pub mod header;
 pub mod input;
+pub mod merkleproof;
+pub mod nipopow;
+
 pub mod prover_result;
+pub mod rest;
 pub mod secret_key;
 pub mod token;
 pub mod transaction;
