@@ -2,7 +2,7 @@
 
 use wasm_bindgen::prelude::*;
 
-use crate::context_extension::ContextExtension;
+use crate::{context_extension::ContextExtension, error_conversion::to_js};
 extern crate derive_more;
 use derive_more::{From, Into};
 
@@ -23,8 +23,8 @@ impl ProverResult {
         self.0.extension.clone().into()
     }
 
-    /// JSON representation
-    pub fn to_json(&self) -> Result<JsValue, JsValue> {
-        JsValue::from_serde(&self.0.clone()).map_err(|e| JsValue::from_str(&format!("{}", e)))
+    /// JSON representation as text (compatible with Ergo Node/Explorer API, numbers are encoded as numbers)
+    pub fn to_json(&self) -> Result<String, JsValue> {
+        serde_json::to_string_pretty(&self.0.clone()).map_err(to_js)
     }
 }
